==> openshift-model-6.7.2-sources.jar: io/fabric8/openshift/api/model/ImageStreamTagBuilder.java <==
package io.fabric8.openshift.api.model;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Boolean;
public class ImageStreamTagBuilder extends ImageStreamTagFluentImpl<ImageStreamTagBuilder> implements VisitableBuilder<ImageStreamTag,ImageStreamTagBuilder>{
  public ImageStreamTagBuilder() {
    this(false);
  }
  public ImageStreamTagBuilder(Boolean validationEnabled) {
    this(new ImageStreamTag(), validationEnabled);
  }
  public ImageStreamTagBuilder(ImageStreamTagFluent<?> fluent) {
    this(fluent, false);
  }
  public ImageStreamTagBuilder(ImageStreamTagFluent<?> fluent,Boolean validationEnabled) {
    this(fluent, new ImageStreamTag(), validationEnabled);
  }
  public ImageStreamTagBuilder(ImageStreamTagFluent<?> fluent,ImageStreamTag instance) {
    this(fluent, instance, false);
  }
  public ImageStreamTagBuilder(ImageStreamTagFluent<?> fluent,ImageStreamTag instance,Boolean validationEnabled) {
    this.fluent = fluent; 
    if (instance != null) {
      fluent.withApiVersion(instance.getApiVersion());
      fluent.withConditions(instance.getConditions());
      fluent.withGeneration(instance.getGeneration());
      fluent.withImage(instance.getImage());
      fluent.withKind(instance.getKind());
      fluent.withLookupPolicy(instance.getLookupPolicy());
      fluent.withMetadata(instance.getMetadata());
      fluent.withTag(instance.getTag());
      fluent.withAdditionalProperties(instance.getAdditionalProperties());
    }
    this.validationEnabled = validationEnabled; 
  }
  public ImageStreamTagBuilder(ImageStreamTag instance) {
    this(instance,false);
  }
  public ImageStreamTagBuilder(ImageStreamTag instance,Boolean validationEnabled) {
    this.fluent = this; 
    if (instance != null) {
      this.withApiVersion(instance.getApiVersion());
      this.withConditions(instance.getConditions());
      this.withGeneration(instance.getGeneration());
      this.withImage(instance.getImage());
      this.withKind(instance.getKind());
      this.withLookupPolicy(instance.getLookupPolicy());
      this.withMetadata(instance.getMetadata());
      this.withTag(instance.getTag());
      this.withAdditionalProperties(instance.getAdditionalProperties());
    }
    this.validationEnabled = validationEnabled; 
  }
  ImageStreamTagFluent<?> fluent;
  Boolean validationEnabled;
  public ImageStreamTag build() {
    ImageStreamTag buildable = new ImageStreamTag(fluent.getApiVersion(),fluent.getConditions(),fluent.getGeneration(),fluent.getImage(),fluent.getKind(),fluent.getLookupPolicy(),fluent.getMetadata(),fluent.getTag());
    buildable.setAdditionalProperties(fluent.getAdditionalProperties());
    return buildable;
  }
  
}

==> openshift-model-6.8.1-sources.jar: io/fabric8/openshift/api/model/ImageStreamTagBuilder.java <==
package io.fabric8.openshift.api.model;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Boolean;
public class ImageStreamTagBuilder extends ImageStreamTagFluent<ImageStreamTagBuilder> implements VisitableBuilder<ImageStreamTag,ImageStreamTagBuilder>{
  public ImageStreamTagBuilder() {
    this(false);
  }
  public ImageStreamTagBuilder(Boolean validationEnabled) {
    this(new ImageStreamTag(), validationEnabled);
  }
  public ImageStreamTagBuilder(ImageStreamTagFluent<?> fluent) {
    this(fluent, false);
  }
  public ImageStreamTagBuilder(ImageStreamTagFluent<?> fluent,Boolean validationEnabled) {
    this(fluent, new ImageStreamTag(), validationEnabled);
  }
  public ImageStreamTagBuilder(ImageStreamTagFluent<?> fluent,ImageStreamTag instance) {
    this(fluent, instance, false);
  }
  public ImageStreamTagBuilder(ImageStreamTagFluent<?> fluent,ImageStreamTag instance,Boolean validationEnabled) {
    this.fluent = fluent; 
    instance = (instance != null ? instance : new ImageStreamTag());

    if (instance != null) {
      fluent.withApiVersion(instance.getApiVersion());
      fluent.withConditions(instance.getConditions());
      fluent.withGeneration(instance.getGeneration());
      fluent.withImage(instance.getImage());
      fluent.withKind(instance.getKind());
      fluent.withLookupPolicy(instance.getLookupPolicy());
      fluent.withMetadata(instance.getMetadata());
      fluent.withTag(instance.getTag());
      fluent.withApiVersion(instance.getApiVersion());
      fluent.withConditions(instance.getConditions());
      fluent.withGeneration(instance.getGeneration());
      fluent.withImage(instance.getImage());
      fluent.withKind(instance.getKind());
      fluent.withLookupPolicy(instance.getLookupPolicy());
      fluent.withMetadata(instance.getMetadata());
      fluent.withTag(instance.getTag());
      fluent.withAdditionalProperties(instance.getAdditionalProperties());
    }
    this.validationEnabled = validationEnabled; 
  }
  public ImageStreamTagBuilder(ImageStreamTag instance) {
    this(instance,false);
  }
  public ImageStreamTagBuilder(ImageStreamTag instance,Boolean validationEnabled) {
    this.fluent = this; 
    instance = (instance != null ? instance : new ImageStreamTag());

    if (instance != null) {
      this.withApiVersion(instance.getApiVersion());
      this.withConditions(instance.getConditions());
      this.withGeneration(instance.getGeneration());
      this.withImage(instance.getImage());
      this.withKind(instance.getKind());
      this.withLookupPolicy(instance.getLookupPolicy());
      this.withMetadata(instance.getMetadata());
      this.withTag(instance.getTag());
      this.withApiVersion(instance.getApiVersion());
      this.withConditions(instance.getConditions());
      this.withGeneration(instance.getGeneration());
      this.withImage(instance.getImage());
      this.withKind(instance.getKind());
      this.withLookupPolicy(instance.getLookupPolicy());
      this.withMetadata(instance.getMetadata());
      this.withTag(instance.getTag());
      this.withAdditionalProperties(instance.getAdditionalProperties());
    }
    this.validationEnabled = validationEnabled; 
  }
  ImageStreamTagFluent<?> fluent;
  Boolean validationEnabled;
  public ImageStreamTag build() {
    ImageStreamTag buildable = new ImageStreamTag(fluent.getApiVersion(),fluent.buildConditions(),fluent.getGeneration(),fluent.buildImage(),fluent.getKind(),fluent.buildLookupPolicy(),fluent.buildMetadata(),fluent.buildTag());
    buildable.setAdditionalProperties(fluent.getAdditionalProperties());
    return buildable;
  }
  
}
